
From: Dominik Brodowski <linux@dominikbrodowski.net>

Schedule removal of the PCMCIA ioctl (and thus kernel support for the
pcmcia-cs userspace package) for November 2005.  

A big "thank you" to Dave Hinds for his great work on supporting PCMCIA in
Linux.  Things are just done differently by now, so the ongoing work to make
PCMCIA behave like any other hotpluggable bus should continue.

Signed-off-by: Dominik Brodowski <linux@dominikbrodowski.net>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 Documentation/feature-removal-schedule.txt |   16 ++++++++++++++++
 drivers/pcmcia/Kconfig                     |   14 +++++---------
 2 files changed, 21 insertions(+), 9 deletions(-)

diff -puN Documentation/feature-removal-schedule.txt~pcmcia-deprecate-ioctl Documentation/feature-removal-schedule.txt
--- devel/Documentation/feature-removal-schedule.txt~pcmcia-deprecate-ioctl	2005-07-06 01:15:26.000000000 -0700
+++ devel-akpm/Documentation/feature-removal-schedule.txt	2005-07-06 01:15:26.000000000 -0700
@@ -111,3 +111,19 @@ Why:	Match the other drivers' name for t
 	will be available until removal of old names.
 Who:	Grant Coady <gcoady@gmail.com>
 
+---------------------------
+
+What:	PCMCIA control ioctl (needed for pcmcia-cs [cardmgr, cardctl])
+When:	November 2005
+Files:	drivers/pcmcia/: pcmcia_ioctl.c
+Why:	With the 16-bit PCMCIA subsystem now behaving (almost) like a
+	normal hotpluggable bus, and with it using the default kernel
+	infrastructure (hotplug, driver core, sysfs) keeping the PCMCIA
+	control ioctl needed by cardmgr and cardctl from pcmcia-cs is
+	unnecessary, and makes further cleanups and integration of the
+	PCMCIA subsystem into the Linux kernel device driver model more
+	difficult. The features provided by cardmgr and cardctl are either
+	handled by the kernel itself now or are available in the new
+	pcmciautils package available at
+	http://kernel.org/pub/linux/utils/kernel/pcmcia/
+Who:	Dominik Brodowski <linux@brodo.de>
diff -puN drivers/pcmcia/Kconfig~pcmcia-deprecate-ioctl drivers/pcmcia/Kconfig
--- devel/drivers/pcmcia/Kconfig~pcmcia-deprecate-ioctl	2005-07-06 01:15:26.000000000 -0700
+++ devel-akpm/drivers/pcmcia/Kconfig	2005-07-06 01:15:26.000000000 -0700
@@ -1,8 +1,5 @@
 #
-# PCMCIA bus subsystem configuration
-#
-# Right now the non-CardBus choices are not supported
-# by the integrated kernel driver.
+# PCCARD (PCMCIA/CardBus) bus subsystem configuration
 #
 
 menu "PCCARD (PCMCIA/CardBus) support"
@@ -32,7 +29,7 @@ config PCMCIA_DEBUG
 
 	  The kernel command line options are:
 	    pcmcia_core.pc_debug=N
-	    ds.pc_debug=N
+	    pcmcia.pc_debug=N
 	    sa11xx_core.pc_debug=N
 
 	  The module option is called pc_debug=N
@@ -73,7 +70,7 @@ config PCMCIA_LOAD_CIS
 	  If unsure, say Y.
 
 config PCMCIA_IOCTL
-	bool
+	bool "PCMCIA control ioctl (obsolete)"
 	depends on PCMCIA
 	default y
 	help
@@ -81,9 +78,8 @@ config PCMCIA_IOCTL
 	  subsystem will be built. It is needed by cardmgr and cardctl
 	  (pcmcia-cs) to function properly.
 
-	  If you do not use the new pcmciautils package, and have a
-	  yenta, Cirrus PD6729, i82092, i82365 or tcic compatible bridge,
-	  you need to say Y here to be able to use 16-bit PCMCIA cards.
+	  You should use the new pcmciautils package instead (see
+	  <file:Documentation/Changes> for location and details).
 
 	  If unsure, say Y.
 
_
